@@ -11,3 +11,10 @@ test_setup <- function(path = tempfile()) {
 test_teardown <- function(path) {
   unlink(path, recursive = TRUE, force = TRUE)
 }
+
+skip_on_cran_windows <- function() {
+  on_cran <- !identical(Sys.getenv("NOT_CRAN"), "true")
+  os <- .Platform$OS.type
+  on_windows <- os == "windows"
+  if (on_cran && on_windows) skip("On CRAN Windows machine")
+}
