@@ -2,6 +2,10 @@ context("wflow_open")
 
 # Setup ------------------------------------------------------------------------
 
+source("setup.R")
+
+skip_on_cran_windows()
+
 # start project in a tempdir
 site_dir <- tempfile("test-wflow_open-")
 suppressMessages(wflow_start(site_dir, change_wd = FALSE,
